@@ -42,7 +42,7 @@ def _setup_ddl_event_listeners():
                         c.type.management is True]
 
             # Find all other columns that are not managed Geometries
-            regular_cols = set(table.c).difference(gis_cols)
+            regular_cols = [x for x in table.c if x not in gis_cols]
 
             # Save original table column list for later
             table.info["_saved_columns"] = table.c
@@ -53,9 +53,11 @@ def _setup_ddl_event_listeners():
 
             if event == 'before-drop':
                 # Drop the managed Geometry columns with DropGeometryColumn()
+                table_schema = table.schema or 'public'
                 for c in gis_cols:
                     stmt = select([
-                        func.DropGeometryColumn('public', table.name, c.name)])
+                        func.DropGeometryColumn(
+                            table_schema, table.name, c.name)])
                     stmt = stmt.execution_options(autocommit=True)
                     bind.execute(stmt)
 
@@ -63,15 +65,19 @@ def _setup_ddl_event_listeners():
             # Restore original column list including managed Geometry columns
             table.columns = table.info.pop('_saved_columns')
 
+            table_schema = table.schema or 'public'
             for c in table.c:
                 # Add the managed Geometry columns with AddGeometryColumn()
                 if isinstance(c.type, Geometry) and c.type.management is True:
                     stmt = select([
                         func.AddGeometryColumn(
-                            table.name, c.name,
+                            table_schema,
+                            table.name,
+                            c.name,
                             c.type.srid,
                             c.type.geometry_type,
-                            c.type.dimension)])
+                            c.type.dimension
+                        )])
                     stmt = stmt.execution_options(autocommit=True)
                     bind.execute(stmt)
 
@@ -80,8 +86,7 @@ def _setup_ddl_event_listeners():
                         c.type.spatial_index is True:
                     bind.execute('CREATE INDEX "idx_%s_%s" ON "%s"."%s" '
                                  'USING GIST (%s)' %
-                                 (table.name, c.name,
-                                  (table.schema or 'public'),
+                                 (table.name, c.name, table_schema,
                                   table.name, c.name))
 
                 # Add spatial indices for the Raster columns
@@ -91,8 +96,7 @@ def _setup_ddl_event_listeners():
                 if isinstance(c.type, Raster) and c.type.spatial_index is True:
                     bind.execute('CREATE INDEX "idx_%s_%s" ON "%s"."%s" '
                                  'USING GIST (ST_ConvexHull(%s))' %
-                                 (table.name, c.name,
-                                  (table.schema or 'public'),
+                                 (table.name, c.name, table_schema,
                                   table.name, c.name))
 
         elif event == 'after-drop':
